@@ -1,10 +1,3 @@
-# Copyright (c) 2014, cPanel, Inc.
-# All rights reserved.
-# http://cpanel.net/
-#
-# This is free software; you can redistribute it and/or modify it under the same
-# terms as Perl itself.  See the LICENSE file for further details.
-
 package Mail::Alias::Reader;
 
 use strict;
@@ -12,9 +5,19 @@ use warnings;
 
 use Mail::Alias::Reader::Parser ();
 
-use Carp ();
+use Carp;
 
-our $VERSION = '0.07_0001';
+BEGIN {
+    use Exporter ();
+    use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+
+    $VERSION = '0.01';
+    @ISA     = qw(Exporter);
+
+    @EXPORT      = ();
+    @EXPORT_OK   = ();
+    %EXPORT_TAGS = ();
+}
 
 =head1 NAME
 
@@ -73,18 +76,18 @@ sub open {
     #
     $opts{'mode'} ||= 'aliases';
 
-    Carp::confess('Unknown parsing mode') unless $opts{'mode'} =~ /^aliases|forward$/;
+    confess('Unknown parsing mode') unless $opts{'mode'} =~ /^aliases|forward$/;
 
     my $fh;
 
     if ( defined $opts{'file'} ) {
-        open( $fh, '<', $opts{'file'} ) or Carp::confess("Unable to open aliases file $opts{'file'}: $!");
+        open( $fh, '<', $opts{'file'} ) or confess("Unable to open aliases file $opts{'file'}: $!");
     }
     elsif ( defined $opts{'handle'} ) {
         $fh = $opts{'handle'};
     }
     else {
-        Carp::confess('No file or file handle specified');
+        confess('No file or file handle specified');
     }
 
     return bless {
@@ -185,8 +188,7 @@ prefix; this is implied in the destination token type, rather.
 Only appears in the prsence of a token typed I<T_DIRECTIVE>  When a mail alias
 destination in the form of C<:directive:I<argument>> is parsed, this contains
 the name of the 'C<directive>' portion.  Of course, the value in the
-'I<argument>' portion is contained in the token's C<value> field, but is
-considered optional, especially in the presence of a directive such as C<:fail>.
+'I<argument>' portion is contained in the token's C<value> field.
 
 =back
 
@@ -238,13 +240,8 @@ during the runtime of this module.
 
 =head1 AUTHOR
 
-Written and maintained by Xan Tronix <xan@cpan.org>.
+Written and maintained by Erin Schoenhals <erin@cpanel.net>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014, cPanel, Inc.
-All rights reserved.
-http://cpanel.net/
-
-This is free software; you can redistribute it and/or modify it under the same
-terms as Perl itself.  See the LICENSE file for further details.
+Copyright(c) 2011 cPanel, Inc.  All rights reserved.
