@@ -1,15 +1,10 @@
-# Copyright (c) 2014, cPanel, Inc.
-# All rights reserved.
-# http://cpanel.net/
-#
-# This is free software; you can redistribute it and/or modify it under the same
-# terms as Perl itself.  See the LICENSE file for further details.
-
 package Mail::Alias::Reader::Token;
 
 use strict;
 use warnings;
 
+use Carp;
+
 =head1 NAME
 
 Mail::Alias::Reader::Token
@@ -28,7 +23,7 @@ my @TOKEN_TYPES = (
     [ 'T_COMMENT'    => qr/#\s*(.*)$/ ],
     [ 'T_STRING'     => qr/("(?:\\.|[^"\\]+)*")/ ],
     [ 'T_COMMA'      => qr/,/ ],
-    [ 'T_DIRECTIVE'  => qr/:([^\:\s]+):([^\:\s,]*)/ ],
+    [ 'T_DIRECTIVE'  => qr/:([^\:\s]+):([^\:\s,]+)/ ],
     [ 'T_COMMAND'    => qr/\|(\S+)/ ],
     [ 'T_ADDRESS'    => qr/([a-z0-9_\-@\.*]+)/i ],
     [ 'T_COLON'      => qr/\:/ ],
@@ -173,21 +168,7 @@ originally parsed to yield the current token object.
 
 sub to_string {
     my ($self) = @_;
-
-    my %SUBSTITUTIONS = (
-        "\r" => '\r',
-        "\n" => '\n',
-        "\t" => '\t',
-        '"'  => '\"'
-    );
-
-    my $value = $self->{'value'};
-
-    if ($value) {
-        foreach my $search ( keys %SUBSTITUTIONS ) {
-            $value =~ s/$search/$SUBSTITUTIONS{$search}/g;
-        }
-    }
+    my $ret;
 
     #
     # Since not every token type has a "value", per se, lazy evaluation is
@@ -195,25 +176,32 @@ sub to_string {
     # part of this hash when dealing with tokens that are anything other than a
     # comment.
     #
-    my %FORMATTERS = (
-        'T_COMMENT'    => sub { "# $value" },
+    my %VALUES = (
+        'T_COMMENT'    => sub { "# $self->{'value'}" },
         'T_COMMA'      => sub { ',' },
         'T_COLON'      => sub { ':' },
         'T_WHITESPACE' => sub { ' ' }
     );
 
-    return $FORMATTERS{ $self->{'type'} }->() if exists $FORMATTERS{ $self->{'type'} };
+    return $VALUES{ $self->{'type'} }->() if exists $VALUES{ $self->{'type'} };
 
-    my $ret;
+    if ( defined $self->{'string'} ) {
 
-    if ( $self->is_directive ) {
-        $ret = ":$self->{'name'}:$value";
+        #
+        # If this token contains its original string representation, then
+        # use that directly.  That way, there's no guesswork involved in how to
+        # properly escape the data for recording to a file.
+        #
+        $ret = $self->{'string'};
     }
-    elsif ( $self->is_command ) {
-        $ret = "|$value";
+    elsif ( $self->isa('T_DIRECTIVE') ) {
+        $ret = ":$self->{'name'}:$self->{'value'}";
+    }
+    elsif ( $self->isa('T_COMMAND') ) {
+        $ret = "|$self->{'value'}";
     }
     else {
-        $ret = $value;
+        $ret = $self->{'value'};
     }
 
     #
@@ -298,8 +286,8 @@ sub tokenize {
     );
 
     my @STRING_ESCAPE_SEQUENCES = (
-        [ qr/\\(0\d*)/       => sub { pack 'C', oct($1) } ],
-        [ qr/\\(x[0-9a-f]+)/ => sub { pack 'C', hex("0$1") } ],
+        [ qr/\\(0\d*)/       => sub { pack 'W', oct($1) } ],
+        [ qr/\\(x[0-9a-f]+)/ => sub { pack 'W', hex("0$1") } ],
         [ qr/\\([rnt])/      => sub { $WHITESPACE{$1} } ],
         [ qr/\\([^rnt])/     => sub { $1 } ]
     );
@@ -318,6 +306,7 @@ sub tokenize {
         #
         if ( $token->isa('T_STRING') ) {
             $token->{'value'} =~ s/^"(.*)"$/$1/s;
+            $token->{'string'} = $token->{'value'};
 
             #
             # Parse for any escape sequences that may be present.
@@ -333,7 +322,9 @@ sub tokenize {
             # contents, copying the data directly into the existing token (so as to
             # not lose the previous reference).
             #
-            %{$token} = %{ $class->tokenize_for_types( $token->{'value'}, @TOKEN_STRING_TYPES )->[0] };
+            my $new_token = $class->tokenize_for_types( $token->{'value'}, @TOKEN_STRING_TYPES )->[0];
+
+            %{$token} = %{$new_token};
         }
     }
 
@@ -350,13 +341,8 @@ __END__
 
 =head1 AUTHOR
 
-Written and maintained by Xan Tronix <xan@cpan.org>.
+Erin Schoenhals E<lt>erin@cpanel.netE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014, cPanel, Inc.
-All rights reserved.
-http://cpanel.net/
-
-This is free software; you can redistribute it and/or modify it under the same
-terms as Perl itself.  See the LICENSE file for further details.
+Copyright(c) 2011 cPanel, Inc.  All rights reserved.
